summaryrefslogtreecommitdiffstats
path: root/kpilot/lib/pilotSerialDatabase.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/lib/pilotSerialDatabase.h')
-rw-r--r--kpilot/lib/pilotSerialDatabase.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kpilot/lib/pilotSerialDatabase.h b/kpilot/lib/pilotSerialDatabase.h
index 51a6ba26d..1da2aaacb 100644
--- a/kpilot/lib/pilotSerialDatabase.h
+++ b/kpilot/lib/pilotSerialDatabase.h
@@ -49,7 +49,7 @@ class KDE_EXPORT PilotSerialDatabase : public PilotDatabase
{
friend class KPilotDeviceLink;
protected:
- PilotSerialDatabase( KPilotDeviceLink *l, const QString &dbName );
+ PilotSerialDatabase( KPilotDeviceLink *l, const TQString &dbName );
PilotSerialDatabase( KPilotDeviceLink *l, const DBInfo *info );
public:
@@ -61,8 +61,8 @@ public:
virtual int writeAppBlock(unsigned char* buffer, int len);
/** returns the number of records in the database, 0 if not open */
virtual unsigned int recordCount() const;
- /** Returns a QValueList of all record ids in the database. */
- virtual QValueList<recordid_t> idList();
+ /** Returns a TQValueList of all record ids in the database. */
+ virtual TQValueList<recordid_t> idList();
/** Reads a record from database by id, returns record length */
virtual PilotRecord* readRecordById(recordid_t id);
/** Reads a record from database, returns the record length */
@@ -95,7 +95,7 @@ public:
/** Purges all Archived/Deleted records from Palm Pilot database */
virtual int cleanup();
- virtual QString dbPathName() const;
+ virtual TQString dbPathName() const;
/**
* Deletes the database (by name, as given in the constructor and
@@ -110,7 +110,7 @@ public:
*/
virtual bool createDatabase(long creator=0,
long type=0, int cardno=0, int flags=0, int version=0);
- QString getDBName() { return fDBName; }
+ TQString getDBName() { return fDBName; }
virtual DBType dbType() const;
@@ -130,7 +130,7 @@ protected:
private:
void setDBHandle(int handle) { fDBHandle = handle; }
- QString fDBName;
+ TQString fDBName;
int fDBHandle;
int fDBSocket;
// Pilot-link 0.12 allocates buffers as needed and resizes them.